# -*- coding: utf-8 -*-

import mod.server.extraServerApi as serverApi
ServerSystem = serverApi.GetServerSystemCls()
commandComp = serverApi.GetEngineCompFactory().CreateCommand(serverApi.GetLevelId())
timerComp = serverApi.GetEngineCompFactory().CreateGame(serverApi.GetLevelId())

class FlumeRideServerSystem(ServerSystem):
    def __init__(self, namespace, systemName):
        ServerSystem.__init__(self, namespace, systemName)
        self.npcIdList = {"panda": "-85899345885", "panda2": "-158913789845", "parrot": "-158913789915", "wolf": "-158913789911"}

        nameSpace, systemName = serverApi.GetEngineNamespace(), serverApi.GetEngineSystemName()
        self.ListenForEvent(nameSpace, systemName, "PlayerAttackEntityEvent", self, self.PlayerAttackEntityEvent)
        self.ListenForEvent(nameSpace, systemName, "ClientLoadAddonsFinishServerEvent", self, self.DataInit)

    def DataInit(self, args):
        playerId = args['playerId']
        playerDataComp = serverApi.GetEngineCompFactory().CreateExtraData(playerId)
        pandaMsgData = playerDataComp.GetExtraData("pandaMsg")
        if not pandaMsgData:
            playerDataComp.SetExtraData("pandaMsg", 0)
            playerDataComp.SetExtraData("parrotMsg", 0)


    def PlayerAttackEntityEvent(self, args):

        def PandaGuide():
            self.NotifyToClient(playerId, "OpenGameInfoUI", {"UIType": "panda"})

        def Panda2Guide():
            playerNameComp = serverApi.GetEngineCompFactory().CreateName(playerId)
            playerName = playerNameComp.GetName()  # 获取玩家的名称
            playerDataComp = serverApi.GetEngineCompFactory().CreateExtraData(playerId)
            pandaMsg = playerDataComp.GetExtraData("pandaMsg")
            commandComp.SetCommand("playsound random.orb " + playerName + " ~ ~ ~ 3 1 1")
            if pandaMsg == 0:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f《丛林激流》欢迎你！ §a(1/6)"}]}')
            elif pandaMsg == 1:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f丛林的小动物们和人类一起建造了这里！ §a(2/6)"}]}')
            elif pandaMsg == 2:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f今天是激流游乐园开业的第一天； §a(3/6)"}]}')
            elif pandaMsg == 3:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f鹦鹉小姐会教你如何在水赛道上更加灵活 §a(4/6)"}]}')
            elif pandaMsg == 4:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f关于丛林激流的一切还可以问问狼先生,他什么都知道 §a(5/6)"}]}')
            elif pandaMsg == 5:
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"熊猫 §a§l| §r§f当然,不要忘了叫上小伙伴一起享受这快乐的游戏时光！ §a(6/6)"}]}')
                playerDataComp.SetExtraData("pandaMsg", 0)
                return
            pandaMsg += 1
            playerDataComp.SetExtraData("pandaMsg", pandaMsg)

        def ParrotGuide():
            playerNameComp = serverApi.GetEngineCompFactory().CreateName(playerId)
            playerName = playerNameComp.GetName()  # 获取玩家的名称
            playerDataComp = serverApi.GetEngineCompFactory().CreateExtraData(playerId)
            parrotMsg = playerDataComp.GetExtraData("parrotMsg")
            if parrotMsg == 0:
                commandComp.SetCommand("tp " + playerName + " 29.5 80 -242.5 -20.4 31.4")
                self.NotifyToClient(playerId, "PlayerCamera", {"Camera": "Lock"})
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"鹦鹉 §e§l| §r§f这是摩托艇,你需要驾驶它驰骋在丛林河道上 §a(1/3)"}]}')
            elif parrotMsg == 1:
                commandComp.SetCommand("tp " + playerName + " 23.6 79 -252.5 54.1 16.4")
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"鹦鹉 §e§l| §r§f在丛林中,你会看到幸运Q块,用弩射击它将会发生随机的事件 §a(2/3)"}]}')
            elif parrotMsg == 2:
                commandComp.SetCommand("tp " + playerName + " 33.4 112 -136.4 -162.6 -7.8")
                commandComp.SetCommand('tellraw ' + playerName + ' {"rawtext":[{"text":"鹦鹉 §e§l| §r§f熟练操控摩托艇,精准射击幸运Q块,在丛林中激流吧！ §a(3/3)"}]}')
            elif parrotMsg == 3:
                commandComp.SetCommand("tp " + playerName + " 22 68 -254 -114.8 0.9")
                self.NotifyToClient(playerId, "PlayerCamera", {"Camera": "UnLock"})
                playerDataComp.SetExtraData("parrotMsg", 0)
                return
            commandComp.SetCommand("playsound random.orb " + playerName + " ~ ~ ~ 3 1 1")
            parrotMsg += 1
            playerDataComp.SetExtraData("parrotMsg", parrotMsg)

        def WolfGuide():
            self.NotifyToClient(playerId, "OpenGameInfoUI", {"UIType": "wolf"})

        playerId = args['playerId']
        entityId = args['victimId']

        if entityId == self.npcIdList["panda"]:
            PandaGuide()

        elif entityId == self.npcIdList["panda2"]:
            Panda2Guide()

        elif entityId == self.npcIdList["parrot"]:
            ParrotGuide()
            timerComp.AddTimer(10, ParrotGuide)
            timerComp.AddTimer(20, ParrotGuide)
            timerComp.AddTimer(30, ParrotGuide)

        elif entityId == self.npcIdList["wolf"]:
            WolfGuide()

